@@ -1,6 +1,7 @@
 
 import os
 import utils
+import shutil
 import uuid
 import datetime
 
@@ -107,6 +108,26 @@ class FilesystemStore(object):
         f.close()
         return size
 
+    def copy(self, source, dest=None):
+        """copy a file from source to destination"""
+        if dest is None:
+            dest = unicode(uuid.uuid4())
+            
+        filepath = self.filepath # the directory path relative to the root
+        fullpath = os.path.join(self.root_path, filepath) # absolute path to directory
+        dest = utils.string2filename(dest, fullpath) # compute a filename
+
+        dest_filename = os.path.join(self.root_path, filepath, dest) # full path to file
+        source_filename = os.path.join(self.root_path, source)
+        path = os.path.split(dest_filename)[0] # directory path
+        print dest_filename, source_filename
+            
+        if not os.path.exists(path):
+            os.makedirs(path) # make sure the path exists
+        shutil.copyfile(source_filename, dest_filename)
+        return os.path.join(filepath, dest)
+
+
     @property
     def filepath(self):
         """the path between root_path and filename"""
